import * as poly2tri from 'poly2tri';
import type { Ring, Triangle } from '@allmaps/types';
/**
 * Triangle as `[[x0, y0], [x1, y1], [x2, y2]]`
 * @typedef {Object} Triangle
 */
/**
 * Triangle object from [poly2tri](https://github.com/r3mi/poly2tri.js/) package
 * @typedef {Object} poly2tri.Triangle
 */
/**
 * Polygon object, as an outer Ring only `[[number, number], ...]`
 * @typedef {Object} Ring
 */
/**
 * Triangulates a polygon (and returns the full Poly2tri output)
 *
 * @remark Use this function to access the rich poly2tri triangulation output (information on constrained edges, neighbours, interior).
 *
 * @param {Ring} polygon - Polygon
 * @param {number} distance - Distance between the Steiner points placed in a grid inside the polygon
 * @returns {poly2tri.Triangle[]} Array of triangles partitioning the polygon
 */
export declare function triangulatePoly2tri(polygon: Ring, distance: number): poly2tri.Triangle[];
/**
 * Triangulates a polygon
 *
 * @remark Polygons with < 3 points just return an empty array.
 *
 * @param {Ring} polygon - Polygon
 * @param {number} distance - Distance between the Steiner points placed in a grid inside the polygon
 * @returns {Triangle[]} Array of triangles partitioning the polygon
 */
export declare function triangulate(polygon: Ring, distance: number): Triangle[];
